# Copyright 2021 The tfaip authors. All Rights Reserved.
#
# This file is part of tfaip.
#
# tfaip is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# tfaip is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# tfaip. If not, see http://www.gnu.org/licenses/.
# ==============================================================================
import tensorflow as tf


class CustomMetric(tf.keras.metrics.Mean):
    """Computes the accuracy of the prediction

    y_true = [B]
    y_pred = [B x N]
    """

    def update_state(self, y_true, y_pred, sample_weight=None):
        trues = tf.cast(y_true, "int64") == tf.argmax(y_pred, axis=-1)
        return super().update_state(tf.cast(trues, "float32"))
